ytree\.arbor\.frontends\.arborarbor\.arbor\.ArborArbor
======================================================

.. currentmodule:: ytree.arbor.frontends.arborarbor.arbor

.. autoclass:: ArborArbor

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ArborArbor.__init__
      ~ArborArbor.add_alias_field
      ~ArborArbor.add_analysis_field
      ~ArborArbor.add_derived_field
      ~ArborArbor.is_grown
      ~ArborArbor.is_setup
      ~ArborArbor.save_arbor
      ~ArborArbor.select_halos
      ~ArborArbor.set_selector
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~ArborArbor.arr
      ~ArborArbor.box_size
      ~ArborArbor.field_info
      ~ArborArbor.hubble_constant
      ~ArborArbor.quan
      ~ArborArbor.size
      ~ArborArbor.trees
      ~ArborArbor.unit_registry
   
   